@@ -2,7 +2,7 @@ package Bio::MUST::Core::Ali;
 # ABSTRACT: Multiple sequence alignment
 # CONTRIBUTOR: Catherine COLSON <ccolson@doct.uliege.be>
 # CONTRIBUTOR: Arnaud DI FRANCO <arnaud.difranco@gmail.com>
-$Bio::MUST::Core::Ali::VERSION = '0.182420';
+$Bio::MUST::Core::Ali::VERSION = '0.190690';
 use Moose;
 use namespace::autoclean;
 
@@ -106,6 +106,11 @@ sub get_seq_with_id {
 }
 
 
+sub all_new_seqs {
+    return shift->filter_seqs( sub { $_->is_new } );
+}
+
+
 sub all_seq_ids {
     my $self = shift;
     return map { $_->seq_id } $self->all_seqs;
@@ -795,7 +800,7 @@ Bio::MUST::Core::Ali - Multiple sequence alignment
 
 =head1 VERSION
 
-version 0.182420
+version 0.190690
 
 =head1 SYNOPSIS
 
@@ -1039,6 +1044,14 @@ the matching logic.
 
 This method requires a single argument.
 
+=head2 all_new_seqs
+
+Returns all the sequences of the Ali tagged as #NEW# (not an array reference).
+
+    my @new_seqs = $ali->all_new_seqs;
+
+This method does not accept any arguments.
+
 =head2 all_seq_ids
 
 Returns all the sequence ids (L<Bio::MUST::Core::SeqId> objects) of the Ali
