@@ -1,6 +1,6 @@
 package Bio::MUST::Core::Taxonomy::ColorScheme;
 # ABSTRACT: Helper class providing color scheme for taxonomic annotations
-$Bio::MUST::Core::Taxonomy::ColorScheme::VERSION = '0.182420';
+$Bio::MUST::Core::Taxonomy::ColorScheme::VERSION = '0.190690';
 use Moose;
 use namespace::autoclean;
 
@@ -102,7 +102,7 @@ sub _build_color_for {
 
 
 sub _build_gcn {
-    return Graphics::ColorNames->new( 'Graphics::ColorNames::WWW' );
+    return Graphics::ColorNames->new('WWW');
 }
 
 sub _build_icol_for {
@@ -245,7 +245,7 @@ Bio::MUST::Core::Taxonomy::ColorScheme - Helper class providing color scheme for
 
 =head1 VERSION
 
-version 0.182420
+version 0.190690
 
 =head1 SYNOPSIS
 
